##  Step 2: Generate and Download a JSON Key
  1. In the Service Accounts page, choose the email address of the service account you created.
  2. Go to the Keys tab.
  3. In the Add key dropdown, select Create new key.
  4. Select JSON as the key type and choose Create.
This downloads the service account key file to your device.
**Caution**
After you download the key file, you cannot download it again.


![Create private key dialog with JSON and P12 key type options in Google Cloud Console.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiodf3350fa3110447d8070bf42f7d1bbc0_LowRes.png)
Creating a Private Key
